@@ -194,7 +194,7 @@ void sindex(int *index, double *jump, double *eval, int *njump, int *neval);
 
 void nclusters(int *npers,int *clusters, int *nclust, int *mclust);
 
-void clusterindex(int *clusters, int *nclust,int *npers,int *idclust, int *clustsize); 
+void clusterindex(int *clusters, int *nclust,int *npers,int *idclust, int *clustsize,int *mednum,int *num); 
  
 void comptest(double *times,int *Ntimes,int *px,double *cu,double *vcu,
 	      double *vcudif,int *antsim,double *test,double *testOBS,
